import 'dart:convert';
import 'package:json_annotation/json_annotation.dart';
import 'package:tautulli/utilities.dart';

part 'newsletter_log_record.g.dart';

/// Model to store an individual newsletter log details from Tautulli.
@JsonSerializable(explicitToJson: true)
class TautulliNewsletterLogRecord {
    /// ID.
    @JsonKey(name: 'id')
    final int id;

    /// Timestamp for when the newsletter was sent.
    @JsonKey(name: 'timestamp', toJson: TautulliUtilities.dateTimeToIntegerMilliseconds, fromJson: TautulliUtilities.millisecondsIntegerToDateTime)
    final DateTime timestamp;

    /// The end date (for content) of the newsletter.
    @JsonKey(name: 'end_date')
    final String endDate;

    /// The start date (for content) of the newsletter.
    @JsonKey(name: 'start_date')
    final String startDate;

    /// The UUID of the newsletter.
    @JsonKey(name: 'uuid')
    final String uuid;

    /// The newsletter ID.
    @JsonKey(name: 'newsletter_id')
    final int newsletterId;

    /// The agent ID for the newsletter.
    @JsonKey(name: 'agent_id')
    final int agentId;

    /// The agent name for the newsletter.
    @JsonKey(name: 'agent_name')
    final String agentName;

    /// The notification action that triggered the notification.
    @JsonKey(name: 'notify_action')
    final String notifyAction;

    /// The subject text of the notification.
    @JsonKey(name: 'subject_text')
    final String subjectText;

    /// Was the notification successfully sent?
    @JsonKey(name: 'success', toJson: TautulliUtilities.booleanToInteger, fromJson: TautulliUtilities.integerToBoolean)
    final bool success;

    TautulliNewsletterLogRecord({
        this.id,
        this.timestamp,
        this.endDate,
        this.startDate,
        this.uuid,
        this.newsletterId,
        this.agentId,
        this.agentName,
        this.notifyAction,
        this.subjectText,
        this.success,
    });

    /// Returns a JSON-encoded string version of this object.
    @override
    String toString() => json.encode(this.toJson());

    /// Deserialize a JSON map to a [TautulliNewsletterLogRecord] object.
    factory TautulliNewsletterLogRecord.fromJson(Map<String, dynamic> json) => _$TautulliNewsletterLogRecordFromJson(json);
    /// Serialize a [TautulliNewsletterLogRecord] object to a JSON map.
    Map<String, dynamic> toJson() => _$TautulliNewsletterLogRecordToJson(this);
}
